@@ -2,7 +2,8 @@ from pathlib import Path
 from typing import Optional, Tuple, Union
 from zipfile import ZipFile
 
-from lnschema_core import id
+from .dev import annotate_bfx_file_type
+from .schema.dev import id
 
 
 class BfxRun:
@@ -16,7 +17,7 @@ class BfxRun:
     ):
         self._biosample_id = biosample_id
         if isinstance(fastq_bcl_path, (str, Path)):
-            self._fastq_path = (Path(fastq_bcl_path),)
+            self._fastq_path = (Path(fastq_bcl_path), None)
         else:
             self._fastq_path = (
                 Path(fastq_bcl_path[0]),  # type: ignore
@@ -27,7 +28,7 @@ class BfxRun:
         self._pipeline_v = pipeline["v"]
         self._pipeline_name = pipeline["name"]
         self._pipeline_reference = pipeline["reference"]
-        self._run_id = id.pipeline_run()
+        self._run_id = id.bfx_run()
 
     @property
     def biosample_id(self):
@@ -49,9 +50,7 @@ class BfxRun:
         """Bfx file types for each dobject."""
         file_type_dict = {}
         for path in self.dobjects:
-            dirpath = path.parent.resolve()
-            file_type = str(dirpath).split("/")[-1]
-            file_type_dict[path] = file_type
+            file_type_dict[path] = annotate_bfx_file_type(path)
         return file_type_dict
 
     @property
