@@ -3,6 +3,8 @@
 .. autosummary::
    :toctree: .
 
+   annotate_bfx_file_type
    generate_cell_ranger_files
 """
+from ._core import annotate_bfx_file_type
 from ._sc import generate_cell_ranger_files  # noqa
