@@ -1,6 +1,8 @@
 from pathlib import Path
 from typing import Union
 
+from lnschema_core.dev import id
+
 
 def generate_cell_ranger_files(sample_name: str, basedir: Union[str, Path]):
     """Generate mock cell ranger outputs.
@@ -43,3 +45,8 @@ def generate_cell_ranger_files(sample_name: str, basedir: Union[str, Path]):
     ]:
         filedir = sampledir / filename
         filedir.touch(exist_ok=True)
+
+    for filepath in basedir.rglob("*"):
+        if not filepath.is_dir():
+            with open(filepath, "w") as file:
+                file.write(f"{id.base62(n_char=6)}")
